This function returns a dataframe with 1 row/column per factor or meta-review.
As in a correlation matrix, the cell at the intersection of a row and a column contains the desired information (i.e. the overlap between primary studies for the column and row names).
Arguments
x
an 'umbrella' object
ID
a character variable indicating whether the overlap should be looked across 'factor' or across 'meta_review'.
presentation
the type of presentation for the overlap. Can be precise percentages ('%') or symbols ('+').
cut_off
a vector of 3 cut-off values used only if the 'presentation' argument is set as '+'.
enhanced
a logical variable indicating whether you want a narrative description of the information stored in the rows/columns returned by this function.
References
Pérez-Bracchiglione, J., Meza, N., Bangdiwala, S. I., Niño de Guzmán, E., Urrútia, G., Bonfill, X., & Madrid, E. (2022). Graphical Representation of Overlap for OVErviews: GROOVE tool. Research synthesis methods, 13(3), 381–388. https://doi.org/10.1002/jrsm.1557